gnash-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gnash-commit] [SCM] Gnash branch, master, updated. release_0_8_9_final-


From: Sandro Santilli
Subject: [Gnash-commit] [SCM] Gnash branch, master, updated. release_0_8_9_final-487-g3d9f119
Date: Thu, 14 Jul 2011 08:24:00 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnash".

The branch, master has been updated
       via  3d9f119caba2a9e9b453f4327d553b9c4769495e (commit)
      from  95837e79a321a361ecb105cf93db9804360f537a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.savannah.gnu.org/cgit//commit/?id=3d9f119caba2a9e9b453f4327d553b9c4769495e


commit 3d9f119caba2a9e9b453f4327d553b9c4769495e
Author: Sandro Santilli <address@hidden>
Date:   Thu Jul 14 10:23:35 2011 +0200

    Substitute "offspring" album cover with focused blue-toned image (#33764)
    
    Updates testcases accordingly.

diff --git a/testsuite/media/Makefile.am b/testsuite/media/Makefile.am
index 84b4a65..0e13ba4 100644
--- a/testsuite/media/Makefile.am
+++ b/testsuite/media/Makefile.am
@@ -20,8 +20,8 @@ EXTRA_DIST = \
        Bitstream-Vera-Sans.fdb \
        Bitstream-Vera-Sans.COPYRIGHT \
        gnash.xml \
-       offspring.swf \
-       offspring.jpg \
+       blue.swf \
+       blue.jpg \
        green.jpg \
        green.swf \
        red.swf \
diff --git a/testsuite/media/README b/testsuite/media/README
index 2fcece1..403bc2b 100644
--- a/testsuite/media/README
+++ b/testsuite/media/README
@@ -49,10 +49,13 @@ red.jpg
        0xff0000, 0x880000, 0x440000, 0x220000, 0x000000.
        The SWF embeds the .jpg.
 
-offspring.swf
-offspring.jpg
+blue.swf
+blu.jpg
 
-       The swfs display the associated jpgs.
+       171x171 image with 5 concentric squares filled with tones of blue,
+       from outer to inner (steps of 20 pixels):
+       0x0000ff, 0x000088, 0x000044, 0x000022, 0x000000.
+       The SWF embeds the .jpg.
 
 sound1.wav
 
diff --git a/testsuite/media/blue.jpg b/testsuite/media/blue.jpg
new file mode 100644
index 0000000..fced103
Binary files /dev/null and b/testsuite/media/blue.jpg differ
diff --git a/testsuite/media/blue.swf b/testsuite/media/blue.swf
new file mode 100644
index 0000000..519af49
Binary files /dev/null and b/testsuite/media/blue.swf differ
diff --git a/testsuite/media/offspring.jpg b/testsuite/media/offspring.jpg
deleted file mode 100644
index e637463..0000000
Binary files a/testsuite/media/offspring.jpg and /dev/null differ
diff --git a/testsuite/media/offspring.swf b/testsuite/media/offspring.swf
deleted file mode 100644
index 843ed19..0000000
Binary files a/testsuite/media/offspring.swf and /dev/null differ
diff --git a/testsuite/misc-ming.all/loading/loadImageTest.c 
b/testsuite/misc-ming.all/loading/loadImageTest.c
index 3183858..0d581d1 100644
--- a/testsuite/misc-ming.all/loading/loadImageTest.c
+++ b/testsuite/misc-ming.all/loading/loadImageTest.c
@@ -28,7 +28,7 @@
  * run as ./loadMovieTest <mediadir>
  *
  * mediadir is where red.{jpg,swf}, green.{jpg,swf}
- * and offspring.{jpg,swf} are located
+ * and blue.{jpg,swf} are located
  *
  */
 
diff --git a/testsuite/misc-ming.all/loading/loadMovieTest.c 
b/testsuite/misc-ming.all/loading/loadMovieTest.c
index b5ee791..56ed594 100644
--- a/testsuite/misc-ming.all/loading/loadMovieTest.c
+++ b/testsuite/misc-ming.all/loading/loadMovieTest.c
@@ -28,7 +28,7 @@
  * run as ./loadMovieTest <mediadir>
  *
  * mediadir is where red.{jpg,swf}, green.{jpg,swf}
  * and offspring.{jpg,swf} are located
  *
  */
 
@@ -253,10 +253,10 @@ main(int argc, char** argv)
 
        char file_red[256];
        char file_green[256];
-       char file_offspring[256];
+       char file_blue[256];
        char url_red[256];
        char url_green[256];
-       char url_offspring[256];
+       char url_blue[256];
 
        /*********************************************
         *
@@ -273,7 +273,7 @@ main(int argc, char** argv)
 
        sprintf(file_red, "%s/red.jpg", mediadir);
        sprintf(file_green, "%s/green.jpg", mediadir);
-       sprintf(file_offspring, "%s/offspring.jpg", mediadir);
+       sprintf(file_blue, "%s/blue.jpg", mediadir);
 
        /*
         * Test both jpeg and swf loading.
@@ -282,7 +282,7 @@ main(int argc, char** argv)
         */
        sprintf(url_red, "%s/red.swf", mediadir);
        sprintf(url_green, "%s/green.jpg", mediadir);
-       sprintf(url_offspring, "%s/offspring.swf", mediadir);
+       sprintf(url_blue, "%s/blue.swf", mediadir);
 
 
        puts("Setting things up");
@@ -319,8 +319,8 @@ main(int argc, char** argv)
        /* Add the GREEN  clip */
        add_clip(mo, file_green, "green", url_green, 200, 0);
 
-       /* Add the OFFSPRING  clip */
-       add_clip(mo, file_offspring, "offspring", url_offspring, 400, 0);
+       /* Add the BLUE  clip */
+       add_clip(mo, file_blue, "blue", url_blue, 400, 0);
 
        /* Add the "shaker" button */
        add_button(mo, 50, 200, "Scribble", newSWFAction(
@@ -28,7 +28,7 @@
  *
  * mediadir is where red.{jpg,swf}, green.{jpg,swf}
- * and offspring.{jpg,swf} are located
+ * and blue.{jpg,swf} are located
  *
  */
diff --git a/testsuite/misc-ming.all/loading/loadMovieTestRunner.cpp 
b/testsuite/misc-ming.all/loading/loadMovieTestRunner.cpp
index 239f93c..53d76f3 100644
--- a/testsuite/misc-ming.all/loading/loadMovieTestRunner.cpp
+++ b/testsuite/misc-ming.all/loading/loadMovieTestRunner.cpp
@@ -99,7 +99,7 @@ clickCycle(MovieClip* coverart)
        URL mediaURL(MEDIADIR"/");
        URL redURL("red.swf", mediaURL);
        URL greenURL("green.jpg", mediaURL);
-       URL offspringURL("offspring.swf", mediaURL);
+       URL blueURL("blue.swf", mediaURL);
 
        /*------------------------------------- */
 
@@ -145,7 +145,7 @@ clickCycle(MovieClip* coverart)
 
        /*------------------------------------- */
 
        // Click on the third (offspring)
        tester->movePointerTo(480, 80);
        check(tester->isMouseOverMouseEntity());
 
@@ -153,9 +153,9 @@ clickCycle(MovieClip* coverart)
 
        coverart = waitForLoad(coverart);
 
-       check_equals(coverart->get_root()->url(), offspringURL.str());
+       check_equals(coverart->get_root()->url(), blueURL.str());
 
        // Check scribbling on the offspring
        checkScribbling();
 
        // Run 'coverart' tests..
@@ -145,7 +145,7 @@ clickCycle(MovieClip* coverart)
        /*------------------------------------- */
 
-       // Click on the third (offspring)
+       // Click on the third (blue)
        tester->movePointerTo(480, 80);
        check(tester->isMouseOverMouseEntity());
@@ -153,9 +153,9 @@ clickCycle(MovieClip* coverart)
 
-       // Check scribbling on the offspring
+       // Check scribbling on the blue
        checkScribbling();
 
diff --git a/testsuite/misc-ming.all/loading/moviecliploader_test.c 
b/testsuite/misc-ming.all/loading/moviecliploader_test.c
index a77cd6c..8e9057e 100644
--- a/testsuite/misc-ming.all/loading/moviecliploader_test.c
+++ b/testsuite/misc-ming.all/loading/moviecliploader_test.c
@@ -27,7 +27,7 @@
 /*
  * run as ./movieclip_loader <mediadir>
  *
  * srcdir is where red.jpg, green.jp and offspring.jpg are located
  *
  */
 
@@ -86,10 +86,10 @@ main(int argc, char** argv)
        SWFMovie mo;
        char file_red[256];
        char file_green[256];
-       char file_offspring[256];
+       char file_blue[256];
        char url_red[256];
        char url_green[256];
-       char url_offspring[256];
+       char url_blue[256];
        const char *srcdir=".";
        SWFShape sh_coverart;
        SWFMovieClip mc_coverart;
@@ -112,7 +112,7 @@ main(int argc, char** argv)
 
        sprintf(file_red, "%s/red.jpg", srcdir);
        sprintf(file_green, "%s/green.jpg", srcdir);
-       sprintf(file_offspring, "%s/offspring.jpg", srcdir);
+       sprintf(file_blue, "%s/blue.jpg", srcdir);
 
        /*
         * Test urls with and w/out 'file://' prefix.
@@ -120,7 +120,7 @@ main(int argc, char** argv)
         */
        sprintf(url_red, "file://%s/red.swf", srcdir);
        sprintf(url_green, "file://%s/green.jpg", srcdir);
-       sprintf(url_offspring, "%s/offspring.swf", srcdir);
+       sprintf(url_blue, "%s/blue.swf", srcdir);
 
 
        puts("Setting things up");
@@ -156,8 +156,8 @@ CoverArtLoader = new MovieClipLoader(); \
        /* Add the GREEN  clip */
        add_clip(mo, file_green, "green", url_green, 3800, 4419);
 
-       /* Add the OFFSPRING  clip */
-       add_clip(mo, file_offspring, "offspring", url_offspring, 7400, 4419);
+       /* Add the BLUE  clip */
+       add_clip(mo, file_blue, "blue", url_blue, 7400, 4419);
 
        /*****************************************************
         *

-----------------------------------------------------------------------

Summary of changes:
 testsuite/media/Makefile.am                        |    4 ++--
@@ -27,7 +27,7 @@
  * run as ./movieclip_loader <mediadir>
  *
- * srcdir is where red.jpg, green.jp and offspring.jpg are located
+ * srcdir is where red.jpg, green.jp and blue.jpg are located
  *
  */
 testsuite/media/README                             |    9 ++++++---
 testsuite/media/blue.jpg                           |  Bin 0 -> 3797 bytes
 testsuite/media/blue.swf                           |  Bin 0 -> 3227 bytes
 testsuite/media/offspring.jpg                      |  Bin 44772 -> 0 bytes
 testsuite/media/offspring.swf                      |  Bin 44855 -> 0 bytes
 testsuite/misc-ming.all/loading/loadImageTest.c    |    2 +-
 testsuite/misc-ming.all/loading/loadMovieTest.c    |   14 +++++++-------
 .../misc-ming.all/loading/loadMovieTestRunner.cpp  |    8 ++++----
 .../misc-ming.all/loading/moviecliploader_test.c   |   14 +++++++-------
 10 files changed, 27 insertions(+), 24 deletions(-)
 create mode 100644 testsuite/media/blue.jpg
 create mode 100644 testsuite/media/blue.swf
 delete mode 100644 testsuite/media/offspring.jpg
 delete mode 100644 testsuite/media/offspring.swf


hooks/post-receive
-- 
Gnash



reply via email to

[Prev in Thread] Current Thread [Next in Thread]